<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0">
<xsl:import href="page_Components.xsl" />
<xsl:param name="targetpath" />
<xsl:param name="pdf_file" />
<xsl:output method="html" name="html"/>

<xsl:template match="/">
<xsl:value-of select="$targetpath" /> 
<xsl:for-each select="/Document/chapter">
<xsl:variable name="bodyfile" select="concat($targetpath,'/',fileName,'.htm')"/>
<xsl:variable name="deeplinkpath" select="concat('http://www.superx-projekt.de',substring-after($targetpath,'webapps/superx'))"/>

Generiere <xsl:value-of select="$bodyfile"/> in <xsl:value-of select="$targetpath"/><xsl:text>
</xsl:text>
<!--output method mit NAME text ist wichtig, damit sich result-document darauf beziehen kann
<xsl:result-document href="{$tabfile}" format="text">-->
<xsl:result-document href="{$bodyfile}" format="html"
method="html">
<xsl:variable name="prev">
<xsl:call-template name="getFilename">
<xsl:with-param name="id" select="@prev" />
</xsl:call-template>
</xsl:variable>
<xsl:variable name="next">
<xsl:call-template name="getFilename">
<xsl:with-param name="id" select="@next" />
</xsl:call-template>
</xsl:variable>
<html>
<head><title><xsl:value-of select="name"/></title>
<META NAME = "author" content = "Daniel Quathamer"></META>
<META NAME = "copyright" content = "{concat('(c) ',format-dateTime(current-dateTime(),'[Y]'),' Daniel Quathamer')}"></META>
<META NAME = "date" content ="{format-dateTime(current-dateTime(),'[D].[M].[Y]')}"></META>
<meta http-equiv="content-type" content="text/html; charset=UTF-8" />
<LINK REL = "Start" href = "main.htm"></LINK>
<LINK REL = "Next" href="{$next}" />
<LINK REL = "Prev" href="{$prev}" />
<LINK REL = "Fokus" href="{$deeplinkpath}"/>
<style type="text/css"><xsl:text>
</xsl:text>
<xsl:value-of select="/Document/style"/>
</style>
<LINK REL="stylesheet" type="text/css" href="superx.css"></LINK>
<base target="_parent" />
</head>
<body>
<!--andre: hier navi-template aufrufen-->
<xsl:variable name="header_tagname">
<xsl:choose>
<xsl:when test="@level=0">
<xsl:text>h1</xsl:text>
</xsl:when>
<xsl:otherwise>
<xsl:value-of select="concat('h',@level)"/>
</xsl:otherwise>
</xsl:choose>
</xsl:variable>
<xsl:element name="{$header_tagname}"><xsl:if test="chapterNumber != ''"><span class="chapterNumber">
<xsl:value-of select="chapterNumber"/></span><xsl:text> </xsl:text></xsl:if>
<xsl:value-of select="name"/></xsl:element>
<xsl:variable name="bodyText">
<xsl:value-of select="body"/>
</xsl:variable>
<xsl:choose>
<xsl:when test="$bodyText='#empty#'">
<xsl:variable name="currentId">
<xsl:value-of select="@id"/>
</xsl:variable>
<xsl:for-each select="/Document/chapter[@parent=$currentId]">
<p><xsl:call-template name="navigationButton">
<xsl:with-param name="targetChapterId" select="@id" />
<xsl:with-param name="caption" select="name" />
</xsl:call-template>
</p>
</xsl:for-each>
</xsl:when>
<xsl:otherwise>
<xsl:copy-of select="$bodyText"/>
</xsl:otherwise>
</xsl:choose>

<div id="navi" class="navi" style="POSITION: relative;">
<table border = "0" width = "100%"><tr>
<!--prev-->
<xsl:call-template name="navigationButton">
<xsl:with-param name="targetChapterId" select="@prev" />
<xsl:with-param name="imgSrc" select="'resultset_previous.svg'" />
<xsl:with-param name="caption" select="'Vorherige'" />
</xsl:call-template>
<!--Hoch-->
<xsl:call-template name="navigationButton">
<xsl:with-param name="targetChapterId" select="0" />
<xsl:with-param name="imgSrc" select="'resultset_up.svg'" />
<xsl:with-param name="caption" select="'Hoch'" />
</xsl:call-template>
<!--Search-->
<xsl:call-template name="navigationButton">
<xsl:with-param name="targetHref"><xsl:text>javascript:document.location=('search/index.htm');</xsl:text></xsl:with-param>
<xsl:with-param name="imgSrc" select="'resultset_search.svg'" />
<xsl:with-param name="caption" select="'Suche'" />
<xsl:with-param name="target" select="'_self'" />
</xsl:call-template>
<!--next-->
<xsl:call-template name="navigationButton">
<xsl:with-param name="targetChapterId" select="@next" />
<xsl:with-param name="imgSrc" select="'resultset_next.svg'" />
<xsl:with-param name="caption" select="'Nächste'" />
</xsl:call-template>

</tr>
</table>
</div>
<xsl:variable name="fokus"><xsl:call-template name="getFilename">
<xsl:with-param name="id" select="@id" />
</xsl:call-template></xsl:variable>
<xsl:call-template name="body_foot" >
<xsl:with-param name="pdf_file" select="$pdf_file" />
<xsl:with-param name="fokus" select="concat('#targetpath#/',$fokus)" />
</xsl:call-template>
</body>
</html>
</xsl:result-document>
</xsl:for-each>
</xsl:template>

<xsl:template name="getFilename">
<xsl:param name="id" />
<xsl:value-of select="concat('f_',/Document/chapter[@id=$id]/fileName,'.htm')"/>
</xsl:template>

<xsl:template name="getName">
<xsl:param name="id" />
<xsl:value-of select="/Document/chapter[@id=$id]/name"/>
</xsl:template>

<xsl:template name="navigationButton">
<xsl:param name="targetChapterId" />
<xsl:param name="imgSrc" />
<xsl:param name="caption" />
<xsl:param name="targetHref" />
<xsl:param name="target" select="'_parent'"/>
<xsl:variable name="targetUrl">
<xsl:choose>
<xsl:when test="$targetHref != ''">
<xsl:value-of select="$targetHref"/>
</xsl:when>
<xsl:otherwise>
<xsl:call-template name="getFilename">
<xsl:with-param name="id" select="$targetChapterId" />
</xsl:call-template>
</xsl:otherwise>
</xsl:choose>
</xsl:variable>
<xsl:variable name="targetName">
<xsl:choose>
<xsl:when test="string($targetChapterId) != '' ">
<xsl:call-template name="getName">
<xsl:with-param name="id" select="$targetChapterId" />
</xsl:call-template>
</xsl:when>
<xsl:otherwise>
<xsl:value-of select="$caption"/>
</xsl:otherwise>
</xsl:choose>
</xsl:variable>

<xsl:choose>
<xsl:when test="$imgSrc=''">
<a name="{$caption}" href = "{$targetUrl}" target = "{$target}" class  = "Navigation"
title="{$targetName}" onMouseOver="this.style.textDecoration='underline';"
onMouseOut=" this.style.textDecoration='none';"><xsl:value-of select="$caption" /></a>
</xsl:when>
<xsl:otherwise>
<td class = "navi"><a name="{$caption}" href = "{$targetUrl}"
target = "{$target}"
class  = "Navigation"
title="{$targetName}" onMouseOver="this.style.textDecoration='underline';"
onMouseOut=" this.style.textDecoration='none';">
<IMG src="{$imgSrc}" ALT="{$targetName}" border="0" /></a>
<br />
<a name="{$caption}" href = "{$targetUrl}" target = "{$target}" class  = "Navigation"
title="{$targetName}" onMouseOver="this.style.textDecoration='underline';"
onMouseOut=" this.style.textDecoration='none';"><xsl:value-of select="$caption" /></a></td>
</xsl:otherwise>
</xsl:choose>
</xsl:template>
</xsl:stylesheet>